/*
Example for Solar_Energy Click

    Date          : Aug 2017.
    Author        : Djordje Rosic

Test configuration STM32 :
    
    MCU             : STM32F107VCT6
    Dev. Board      : EasyMx PRO v7 for STM32 ARM
    SW              : mikroC PRO for ARM v5.1.0

Description :

    Following example will charge the battery if it is empty, and stop charging
    when the battery is full. When battery full status is detected, device is
    disabled, but will check battery status every 10 seconds.

*/
sbit SOLAR_EN_PIN at GPIOD_ODR.B13;
sbit SOLAR_INT_PIN at GPIOD_IDR.B10;
void systemInit()
{
    GPIO_Digital_Output( &GPIOD_ODR, _GPIO_PINMASK_13 );
    GPIO_Digital_Input ( &GPIOD_ODR, _GPIO_PINMASK_10 );
}

void Solar_Energy_Init()
{
    SOLAR_EN_PIN = 0;
}

void Solar_Energy_Task()
{
    if (SOLAR_INT_PIN)
    {
        SOLAR_EN_PIN = 1;
        Delay_ms (10000);
    }
    else
    {
        SOLAR_EN_PIN = 0;
    }
}

void main()
{
    systemInit();
    Solar_Energy_Init();

    while( 1 )
    {
            Solar_Energy_Task();
    }
}